==> global_chem_extensions-0.5.7.tar.gz: global_chem_extensions-0.5.7/global_chem_extensions/validation/partial_smiles.py <==
#!/usr/bin/env python3
#
# GlobalChemExtensions - Partial SMILES
#
# --------------------------------------

# Imports
# -------

import urllib.request
from urllib.parse import quote

# Validation Imports
# ------------------

import partialsmiles as ps

from rdkit import Chem
from pysmiles import read_smiles
from molvs import validate_smiles

class PartialSmilesValidation(object):

    __version__ = '0.0.1'


    def __init__(self,
                 partial=False
                 ):

        self.partial = partial

    def validate(
            self,
            smiles_list,
            partial_smiles=True,
            rdkit=True,
            pysmiles=True,
            molvs=True,
    ):

        '''

        Validate the SMILES

        Arguments:
            smiles_list (List): List of SMILES that the user would like to put
            partial_smiles (Bool): Partial SMILES
            rdkit (Bool): whether to include rdkit
            pysmiles (Bool): whether to include pysmiles
            molvs (Bool): whether to include molvs

        Returns:
            successes (List): List of SMILES that worked
            failures (List): List of failed smiles that didn't work.

        '''


        successes = []
        failures = []

        for smiles in smiles_list:
            try:
                if partial_smiles:
                    mol = ps.ParseSmiles(smiles, partial=self.partial)
                if rdkit:
                    mol = Chem.MolFromSmiles(smiles)
                if pysmiles:
                    mol = read_smiles(smiles)
                if molvs:
                    errors = validate_smiles(smiles)
                    for error in errors:
                        if 'ERROR' in error:
                            raise Exception
                successes.append(smiles)
            except Exception as e:
                failures.append(smiles)

        return successes, failures

==> global_chem_extensions-0.7.3.tar.gz: global_chem_extensions-0.7.3/global_chem_extensions/validation/partial_smiles.py <==
#!/usr/bin/env python3
#
# GlobalChemExtensions - Partial SMILES
#
# --------------------------------------

# Imports
# -------

import urllib.request
from urllib.parse import quote

# Validation Imports
# ------------------

import deepsmiles
import partialsmiles as ps

from rdkit import Chem
from pysmiles import read_smiles
from molvs import validate_smiles

class PartialSmilesValidation(object):

    __version__ = '0.0.1'


    def __init__(self,
                 partial=False
                 ):

        self.partial = partial
        self.deep_smiles_converter = deepsmiles.Converter(rings=True, branches=True)

    def validate(
            self,
            smiles_list,
            partial_smiles = True,
            rdkit = False,
            pysmiles = False,
            molvs = False,
            deepsmiles = False,
    ):

        '''

        Validate the SMILES

        Arguments:
            smiles_list (List): List of SMILES that the user would like to put
            partial_smiles (Bool): Partial SMILES
            rdkit (Bool): whether to include rdkit
            pysmiles (Bool): whether to include pysmiles
            molvs (Bool): whether to include molvs
            deepsmiles (Bool): deepSMILES validation for machine learning

        Returns:
            successes (List): List of SMILES that worked
            failures (List): List of failed smiles that didn't work.

        '''


        successes = []
        failures = []

        for smiles in smiles_list:
            try:
                if partial_smiles:
                    mol = ps.ParseSmiles(smiles, partial=self.partial)
                if rdkit:
                    mol = Chem.MolFromSmiles(smiles)
                if pysmiles:
                    mol = read_smiles(smiles)
                if molvs:
                    errors = validate_smiles(smiles)
                    for error in errors:
                        if 'ERROR' in error:
                            raise Exception
                if deepsmiles:

                    encoded = self.deep_smiles_converter.encode(smiles)
                    try:
                        decoded = self.deep_smiles_converter.decode(encoded)
                    except deepsmiles.DecodeError as e:
                        continue
                successes.append(smiles)

            except Exception as e:
                failures.append(smiles)

        return successes, failures
